@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #pragma once
@@ -192,8 +196,9 @@ namespace wb {
 
     class MYSQLWBBACKEND_PUBLIC_FUNC IndexData : public LSTData {
     public:
-      IndexData() : LSTData(), unique(false), type(0) {
+      IndexData() : LSTData(), visible(true), unique(false), type(0) {
       }
+      bool visible;
       bool unique;
       unsigned char type;
       std::vector<std::string> columns;
@@ -339,7 +344,7 @@ namespace wb {
       NodeChildrenUpdaterSlot;
 
     struct FetchDelegate {
-      virtual std::list<std::string> fetch_schema_list() = 0;
+      virtual std::vector<std::string> fetch_schema_list() = 0;
       virtual bool fetch_data_for_filter(const std::string&, const std::string&,
                                          const NewSchemaContentArrivedSlot&) = 0;
       virtual bool fetch_schema_contents(const std::string&, const NewSchemaContentArrivedSlot&) = 0;
