@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "wb_sql_editor_form.h"
@@ -44,9 +48,10 @@
 #include "grtui/file_charset_dialog.h"
 #include "grtsqlparser/mysql_parser_services.h"
 
+#include "mysql/MySQLRecognizerCommon.h"
+
 #include <fstream>
 #include <sstream>
-#include <boost/lexical_cast.hpp>
 
 // 20 MB max file size for auto-restoring
 #define MAX_FILE_SIZE_FOR_AUTO_RESTORE 20000000
@@ -59,10 +64,10 @@ using namespace base;
 //--------------------------------------------------------------------------------------------------
 
 SqlEditorPanel::SqlEditorPanel(SqlEditorForm *owner, bool is_scratch, bool start_collapsed)
-  : mforms::AppView(false, "db.query.QueryBuffer", false),
+  : mforms::AppView(false, "Query Buffer", "db.query.QueryBuffer", false),
     _form(owner),
     _editor_box(false),
-    _splitter(false, true),
+    _splitter(false, false),
 #ifdef __APPLE__
     _lower_tabview(mforms::TabViewEditorBottomPinnable), // TODO: Windows, Linux
 #else
@@ -85,15 +90,14 @@ SqlEditorPanel::SqlEditorPanel(SqlEditorForm *owner, bool is_scratch, bool start
 
   // In opposition to the object editors, each individual sql editor gets an own parser context
   // (and hence an own parser), to allow concurrent and multi threaded work.
-  parser::MySQLParserServices::Ref services = parser::MySQLParserServices::get();
+  parsers::MySQLParserServices::Ref services = parsers::MySQLParserServices::get();
 
-  parser::MySQLParserContext::Ref context = services->createParserContext(
-    owner->rdbms()->characterSets(), owner->rdbms_version(), owner->lower_case_table_names() != 0);
+  parsers::MySQLParserContext::Ref context = services->createParserContext(
+    owner->rdbms()->characterSets(), owner->rdbms_version(), owner->sql_mode(), owner->lower_case_table_names() != 0);
 
-  _editor = MySQLEditor::create(context, owner->work_parser_context(), grtobj);
-  _editor->sql_check_progress_msg_throttle(
-    bec::GRTManager::get()->get_app_option_int("DbSqlEditor:ProgressStatusUpdateInterval", 500) / (double)1000);
-  _editor->set_auto_completion_cache(owner->auto_completion_cache());
+  long version = long(owner->rdbms_version()->majorNumber() * 100 + owner->rdbms_version()->minorNumber());
+  parsers::SymbolTable *functionSymbols = parsers::functionSymbolsForVersion(version);
+  _editor = MySQLEditor::create(context, owner->work_parser_context(), { functionSymbols, owner->databaseSymbols() }, grtobj);
   _editor->set_sql_mode(owner->sql_mode());
   _editor->set_current_schema(owner->active_schema());
   UIForm::scoped_connect(_editor->text_change_signal(), std::bind(&SqlEditorPanel::update_title, this));
@@ -101,7 +105,8 @@ SqlEditorPanel::SqlEditorPanel(SqlEditorForm *owner, bool is_scratch, bool start
   add(&_splitter, true, true);
 
   mforms::CodeEditor *code_editor = editor_be()->get_editor_control();
-  code_editor->set_name("code editor");
+  code_editor->set_name("Code Editor");
+  code_editor->setInternalName("code editor");
   _editor_box.add(setup_editor_toolbar(), false, true);
   _editor_box.add_end(code_editor, true, true);
 
@@ -114,8 +119,12 @@ SqlEditorPanel::SqlEditorPanel(SqlEditorForm *owner, bool is_scratch, bool start
   if (start_collapsed)
     _editor->get_editor_control()->set_size(-1, 25);
 
-  _splitter.add(&_editor_box);
-  _splitter.add(&_lower_tabview);
+  _splitter.add(&_editor_box, 150);
+  _splitter.add(&_lower_tabview, 150);
+  _editor_box.set_name("Editor Area");
+  _editor_box.setInternalName("Editor area");
+  _lower_tabview.set_name("Resultset Placeholder");
+  _lower_tabview.setInternalName("Resultset placeholder");
 
   UIForm::scoped_connect(_splitter.signal_position_changed(), std::bind(&SqlEditorPanel::splitter_resized, this));
   _tab_action_box.set_spacing(4);
@@ -133,12 +142,12 @@ SqlEditorPanel::SqlEditorPanel(SqlEditorForm *owner, bool is_scratch, bool start
   _tab_action_revert.set_text("Revert");
   _tab_action_revert.signal_clicked()->connect(std::bind(&SqlEditorPanel::revert_clicked, this));
 
-#ifdef _WIN32
+#ifdef _MSC_VER
   // 19 is the size of the tabs in the bottom tabview.
   _tab_action_apply.set_size(-1, 19);
   _tab_action_revert.set_size(-1, 19);
   _tab_action_box.set_size(-1, 19);
-  _tab_action_box.set_back_color(Color::get_application_color_as_string(AppColorTabUnselected, false));
+  _tab_action_box.set_back_color(Color::getApplicationColorAsString(AppColorTabUnselected, false));
 #endif
 
   _lower_tabview.set_aux_view(&_tab_action_box);
@@ -159,12 +168,12 @@ SqlEditorPanel::SqlEditorPanel(SqlEditorForm *owner, bool is_scratch, bool start
   set_on_close(std::bind(&SqlEditorPanel::on_close_by_user, this));
 
   _lower_tab_menu.signal_will_show()->connect(std::bind(&SqlEditorPanel::tab_menu_will_show, this));
-  _lower_tab_menu.add_item_with_title("Rename Tab", std::bind(&SqlEditorPanel::rename_tab_clicked, this), "rename");
-  _lower_tab_menu.add_check_item_with_title("Pin Tab", std::bind(&SqlEditorPanel::pin_tab_clicked, this), "pin");
+  _lower_tab_menu.add_item_with_title("Rename Tab", std::bind(&SqlEditorPanel::rename_tab_clicked, this), "Rename Tab", "rename");
+  _lower_tab_menu.add_check_item_with_title("Pin Tab", std::bind(&SqlEditorPanel::pin_tab_clicked, this), "Pin Tab", "pin");
   _lower_tab_menu.add_separator();
-  _lower_tab_menu.add_item_with_title("Close Tab", std::bind(&SqlEditorPanel::close_tab_clicked, this), "close");
+  _lower_tab_menu.add_item_with_title("Close Tab", std::bind(&SqlEditorPanel::close_tab_clicked, this), "Close Tab", "close");
   _lower_tab_menu.add_item_with_title("Close Other Tabs", std::bind(&SqlEditorPanel::close_other_tabs_clicked, this),
-                                      "close_others");
+                                      "Close Other Tabs", "close_others");
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -725,14 +734,16 @@ static void toggle_continue_on_error(SqlEditorForm *sql_editor_form) {
 //--------------------------------------------------------------------------------------------------
 
 mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
-  mforms::ToolBar *tbar(mforms::manage(new mforms::ToolBar(mforms::SecondaryToolBar)));
-#ifdef _WIN32
+  mforms::ToolBar *tbar(mforms::manage(new mforms::ToolBar(mforms::OptionsToolBar)));
+  tbar->set_name("Editor Toolbar");
+#ifdef _MSC_VER
   tbar->set_size(-1, 27);
 #endif
   mforms::ToolBarItem *item;
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.openFile");
+  item->set_name("Open File");
+  item->setInternalName("query.openFile");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_open.png"));
   item->set_tooltip(_("Open a script file in this editor"));
   bec::UIForm::scoped_connect(
@@ -742,7 +753,8 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_item(item);
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.saveFile");
+  item->set_name("Save File");
+  item->setInternalName("query.saveFile");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_save.png"));
   item->set_tooltip(_("Save the script to a file."));
   bec::UIForm::scoped_connect(item->signal_activated(), std::bind(&SqlEditorPanel::save, this));
@@ -751,28 +763,32 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_item(mforms::manage(new mforms::ToolBarItem(mforms::SeparatorItem)));
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.execute");
+  item->set_name("Execute");
+  item->setInternalName("query.execute");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_execute.png"));
   item->set_tooltip(_("Execute the selected portion of the script or everything, if there is no selection"));
   bec::UIForm::scoped_connect(item->signal_activated(), std::bind(&SqlEditorForm::run_editor_contents, _form, false));
   tbar->add_item(item);
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.execute_current_statement");
+  item->set_name("Execute Current Statement");
+  item->setInternalName("query.execute_current_statement");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_execute-current.png"));
   item->set_tooltip(_("Execute the statement under the keyboard cursor"));
   bec::UIForm::scoped_connect(item->signal_activated(), std::bind(&SqlEditorForm::run_editor_contents, _form, true));
   tbar->add_item(item);
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.explain_current_statement");
+  item->set_name("Explain Current Statement");
+  item->setInternalName("query.explain_current_statement");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_explain.png"));
   item->set_tooltip(_("Execute the EXPLAIN command on the statement under the cursor"));
   bec::UIForm::scoped_connect(item->signal_activated(), std::bind(&SqlEditorForm::explain_current_statement, _form));
   tbar->add_item(item);
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.cancel");
+  item->set_name("Cancel");
+  item->setInternalName("query.cancel");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_stop.png"));
   item->set_tooltip(
     _("Stop the query being executed (the connection to the DB server will not be restarted and any open transactions "
@@ -783,7 +799,8 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_item(mforms::manage(new mforms::ToolBarItem(mforms::SeparatorItem)));
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ToggleItem));
-  item->set_name("query.continueOnError");
+  item->set_name("Continue On Error");
+  item->setInternalName("query.continueOnError");
   item->set_alt_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_stop-on-error-on.png"));
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_stop-on-error-off.png"));
   item->set_tooltip(_("Toggle whether execution of SQL script should continue after failed statements"));
@@ -794,7 +811,8 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_item(mforms::manage(new mforms::ToolBarItem(mforms::SeparatorItem)));
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.commit");
+  item->set_name("Commit");
+  item->setInternalName("query.commit");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_commit.png"));
   item->set_tooltip(
     _("Commit the current transaction.\nNOTE: all query tabs in the same connection share the same transaction. To "
@@ -803,7 +821,8 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_item(item);
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("query.rollback");
+  item->set_name("Rollback");
+  item->setInternalName("query.rollback");
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_rollback.png"));
   item->set_tooltip(
     _("Rollback the current transaction.\nNOTE: all query tabs in the same connection share the same transaction. To "
@@ -812,7 +831,8 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_item(item);
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ToggleItem));
-  item->set_name("query.autocommit");
+  item->set_name("Auto Commit");
+  item->setInternalName("query.autocommit");
   item->set_alt_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_autocommit-on.png"));
   item->set_icon(IconManager::get_instance()->get_icon_path("qe_sql-editor-tb-icon_autocommit-off.png"));
   item->set_tooltip(_(
@@ -824,7 +844,8 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_separator_item();
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::SelectorItem));
-  item->set_name("limit_rows");
+  item->set_name("Limit Rows");
+  item->setInternalName("limit_rows");
   item->set_tooltip(
     _("Set limit for number of rows returned by queries.\nWorkbench will automatically add the LIMIT clause with the "
       "configured number of rows to SELECT queries."));
@@ -834,7 +855,8 @@ mforms::ToolBar *SqlEditorPanel::setup_editor_toolbar() {
   tbar->add_separator_item();
 
   item = mforms::manage(new mforms::ToolBarItem(mforms::ActionItem));
-  item->set_name("add_snippet");
+  item->set_name("Add Snippet");
+  item->setInternalName("add_snippet");
   item->set_icon(IconManager::get_instance()->get_icon_path("snippet_add.png"));
   item->set_tooltip(_("Save current statement or selection to the snippet list."));
   bec::UIForm::scoped_connect(item->signal_activated(), std::bind(&SqlEditorForm::save_snippet, _form));
@@ -948,7 +970,7 @@ void SqlEditorPanel::update_title() {
  */
 void SqlEditorPanel::list_members() {
   if (owner()->work_parser_context() != NULL)
-    editor_be()->show_auto_completion(false, owner()->work_parser_context());
+    editor_be()->show_auto_completion(false);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1077,7 +1099,7 @@ void SqlEditorPanel::lower_tab_switched() {
     _tab_action_revert.set_enabled(false);
   }
 
-#ifdef _WIN32
+#ifdef _MSC_VER
   _editor->focus();
 #endif
 
@@ -1253,9 +1275,9 @@ void SqlEditorPanel::lower_tab_reordered(mforms::View *view, int from, int to) {
       }
     }
   }
+
   if (to_index < 0) {
-    logFatal("Unable to find suitable target index for reorder\n");
-    return;
+    to_index = panels.back().second;
   }
 
   grtobj()->resultPanels()->reorder(from_index, to_index);
