@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "connection_figure.h"
@@ -150,6 +154,9 @@ Connection::Connection(mdc::Layer *layer, FigureEventHub *hub, model_Object *rep
 
   _start_figure = 0;
   _end_figure = 0;
+
+  set_pen_color(base::Color::getSystemColor(base::TextColor));
+  set_fill_color(base::Color::getSystemColor(base::TextBackgroundColor));
 }
 
 void Connection::set_start_figure(mdc::CanvasItem *item) {
@@ -559,12 +566,6 @@ void Connection::render(mdc::CairoCtx *cr) {
   if (_segments.empty())
     return;
 
-  // sanity/debugging check
-  // if (_content_cache)
-  //  throw std::logic_error("connection figure is caching its contents");
-
-  // mdc::Line::render(cr);
-
   draw_state(cr);
 
   cr->translate(get_position());
@@ -572,29 +573,9 @@ void Connection::render(mdc::CairoCtx *cr) {
   cr->set_line_width(_line_width);
   cr->set_color(_pen_color);
 
-  /*
-  if (_start_dashed || _end_dashed)
-  {
-    stroke_outline(cr, 0, true);
-    if (_start_dashed)
-      set_line_pattern(cr, mdc::Dashed1Pattern);
-    else
-      set_line_pattern(cr, _line_pattern);
-    cr->stroke();
-
-    stroke_outline(cr, 0, false);
-    if (_end_dashed)
-      set_line_pattern(cr, mdc::Dashed1Pattern);
-    else
-      set_line_pattern(cr, _line_pattern);
-    cr->stroke();
-  }
-  else*/
-  {
-    stroke_outline(cr);
-    set_line_pattern(cr, _line_pattern);
-    cr->stroke();
-  }
+  stroke_outline(cr);
+  set_line_pattern(cr, _line_pattern);
+  cr->stroke();
 
   cr->set_dash(0, 0, 0);
 
@@ -621,7 +602,7 @@ void Connection::render(mdc::CairoCtx *cr) {
       cr->line_to(-10, 0);
       cr->line_to(0, -10);
       cr->close_path();
-      cr->set_color(Color::Black());
+      cr->set_color(Color::black());
       cr->fill();
       break;
     case LeftEmpty:
@@ -632,9 +613,9 @@ void Connection::render(mdc::CairoCtx *cr) {
       cr->line_to(-10, 0);
       cr->line_to(0, -10);
       cr->close_path();
-      cr->set_color(Color::White());
+      cr->set_color(Color::white());
       cr->fill_preserve();
-      cr->set_color(Color::Black());
+      cr->set_color(Color::black());
       cr->stroke();
       cr->new_path();
       cr->move_to(0, -10);
@@ -652,9 +633,9 @@ void Connection::render(mdc::CairoCtx *cr) {
       cr->line_to(-10, 0);
       cr->line_to(0, -10);
       cr->close_path();
-      cr->set_color(Color::White());
+      cr->set_color(Color::white());
       cr->fill_preserve();
-      cr->set_color(Color::Black());
+      cr->set_color(Color::black());
       cr->stroke();
       cr->new_path();
       cr->move_to(0, -10);
@@ -672,9 +653,9 @@ void Connection::render(mdc::CairoCtx *cr) {
       cr->line_to(-10, 0);
       cr->line_to(0, -10);
       cr->close_path();
-      cr->set_color(Color::White());
+      cr->set_color(Color::white());
       cr->fill_preserve();
-      cr->set_color(Color::Black());
+      cr->set_color(Color::black());
       cr->stroke();
       break;
   }
@@ -728,7 +709,7 @@ void Connection::render_gl(mdc::CairoCtx *cr) {
       Point vertices[] = {
         Point(0, -10), Point(10, 0), Point(0, 10), Point(-10, 0), Point(0, -10),
       };
-      gl_setcolor(Color::Black());
+      gl_setcolor(Color::black());
       gl_polygon(vertices, 5, true);
       break;
     }
@@ -737,15 +718,15 @@ void Connection::render_gl(mdc::CairoCtx *cr) {
       Point vertices[] = {
         Point(0, -10), Point(10, 0), Point(0, 10), Point(-10, 0), Point(0, -10),
       };
-      gl_setcolor(Color::Black());
-      gl_polygon(vertices, 5, Color::Black(), Color::White());
+      gl_setcolor(Color::black());
+      gl_polygon(vertices, 5, Color::black(), Color::white());
     }
 
       {
         Point vertices[] = {
           Point(0, -10), Point(10, 0), Point(0, 10), Point(0, -10),
         };
-        gl_polygon(vertices, 4, Color::Black(), Color::White());
+        gl_polygon(vertices, 4, Color::black(), Color::white());
       }
       break;
 
@@ -753,14 +734,14 @@ void Connection::render_gl(mdc::CairoCtx *cr) {
       Point vertices[] = {
         Point(0, -10), Point(10, 0), Point(0, 10), Point(-10, 0), Point(0, -10),
       };
-      gl_polygon(vertices, 5, Color::Black(), Color::White());
+      gl_polygon(vertices, 5, Color::black(), Color::white());
     }
 
       {
         Point vertices[] = {
           Point(0, -10), Point(10, 0), Point(0, 10), Point(0, -10),
         };
-        gl_setcolor(Color::Black());
+        gl_setcolor(Color::black());
         gl_polygon(vertices, 4, true);
       }
 
@@ -769,7 +750,7 @@ void Connection::render_gl(mdc::CairoCtx *cr) {
       Point vertices[] = {
         Point(0, -10), Point(10, 0), Point(0, 10), Point(-10, 0), Point(0, -10),
       };
-      gl_polygon(vertices, 5, Color::Black(), Color::White());
+      gl_polygon(vertices, 5, Color::black(), Color::white());
     } break;
   }
 
