@@ -26,13 +26,14 @@
 #import <Foundation/NSGeometry.h>
 
 #import "Platform.h"
-#import "ScintillaView.h"
-#import "ScintillaCocoa.h"
-#import "PlatCocoa.h"
 
 #include "StringCopy.h"
 #include "XPM.h"
 
+#import "ScintillaView.h"
+#import "ScintillaCocoa.h"
+#import "PlatCocoa.h"
+
 using namespace Scintilla;
 
 extern sptr_t scintilla_send_message(void* sci, unsigned int iMessage, uptr_t wParam, sptr_t lParam);
@@ -113,7 +114,7 @@ Font::~Font()
 //--------------------------------------------------------------------------------------------------
 
 static int FontCharacterSet(Font &f) {
-	return reinterpret_cast<QuartzTextStyle *>(f.GetID())->getCharacterSet();
+	return static_cast<QuartzTextStyle *>(f.GetID())->getCharacterSet();
 }
 
 /**
@@ -137,7 +138,7 @@ void Font::Create(const FontParameters &fp)
 void Font::Release()
 {
   if (fid)
-    delete reinterpret_cast<QuartzTextStyle*>( fid );
+    delete static_cast<QuartzTextStyle*>( fid );
   fid = 0;
 }
 
@@ -216,14 +217,14 @@ void SurfaceImpl::Init(WindowID)
 void SurfaceImpl::Init(SurfaceID sid, WindowID)
 {
   Release();
-  gc = reinterpret_cast<CGContextRef>(sid);
+  gc = static_cast<CGContextRef>(sid);
   CGContextSetLineWidth(gc, 1.0);
   textLayout->setContext(gc);
 }
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::InitPixMap(int width, int height, Surface* /* surface_ */, WindowID /* wid */)
+void SurfaceImpl::InitPixMap(int width, int height, Surface* surface_, WindowID /* wid */)
 {
   Release();
 
@@ -269,6 +270,18 @@ void SurfaceImpl::InitPixMap(int width, int height, Surface* /* surface_ */, Win
     CGContextSetRGBFillColor( gc, 1.0, 1.0, 1.0, 1.0 );
     CGContextFillRect( gc, CGRectMake( 0, 0, width, height ) );
   }
+
+  if (surface_)
+  {
+    SurfaceImpl *psurfOther = static_cast<SurfaceImpl *>(surface_);
+    unicodeMode = psurfOther->unicodeMode;
+    codePage = psurfOther->codePage;
+  }
+  else
+  {
+    unicodeMode = true;
+    codePage = SC_CP_UTF8;
+  }
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -468,16 +481,17 @@ void SurfaceImpl::FillRectangle(PRectangle rc, ColourDesired back)
 
 //--------------------------------------------------------------------------------------------------
 
-void drawImageRefCallback(CGImageRef pattern, CGContextRef gc)
+static void drawImageRefCallback(void *info, CGContextRef gc)
 {
+  CGImageRef pattern = static_cast<CGImageRef>(info);
   CGContextDrawImage(gc, CGRectMake(0, 0, CGImageGetWidth(pattern), CGImageGetHeight(pattern)), pattern);
 }
 
 //--------------------------------------------------------------------------------------------------
 
-void releaseImageRefCallback(CGImageRef pattern)
+static void releaseImageRefCallback(void *info)
 {
-  CGImageRelease(pattern);
+  CGImageRelease(static_cast<CGImageRef>(info));
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -494,9 +508,7 @@ void SurfaceImpl::FillRectangle(PRectangle rc, Surface &surfacePattern)
     return;
   }
 
-  const CGPatternCallbacks drawImageCallbacks = { 0,
-    reinterpret_cast<CGPatternDrawPatternCallback>(drawImageRefCallback),
-    reinterpret_cast<CGPatternReleaseInfoCallback>(releaseImageRefCallback) };
+  const CGPatternCallbacks drawImageCallbacks = { 0, drawImageRefCallback, releaseImageRefCallback };
 
   CGPatternRef pattern = CGPatternCreate(image,
                                          CGRectMake(0, 0, patternSurface.bitmapWidth, patternSurface.bitmapHeight),
@@ -696,7 +708,7 @@ void Scintilla::SurfaceImpl::AlphaRectangle(PRectangle rc, int cornerSize, Colou
 }
 
 static void ProviderReleaseData(void *, const void *data, size_t) {
-	const unsigned char *pixels = reinterpret_cast<const unsigned char *>(data);
+	const unsigned char *pixels = static_cast<const unsigned char *>(data);
 	delete []pixels;
 }
 
@@ -916,12 +928,12 @@ void SurfaceImpl::DrawTextTransparent(PRectangle rc, Font &font_, XYPOSITION yba
 	ColourDesired colour(fore.AsLong());
 	CGColorRef color = CGColorCreateGenericRGB(colour.GetRed()/255.0,colour.GetGreen()/255.0,colour.GetBlue()/255.0,1.0);
 
-	QuartzTextStyle* style = reinterpret_cast<QuartzTextStyle*>(font_.GetID());
+	QuartzTextStyle* style = static_cast<QuartzTextStyle*>(font_.GetID());
 	style->setCTStyleColor(color);
 
 	CGColorRelease(color);
 
-	textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *reinterpret_cast<QuartzTextStyle*>(font_.GetID()));
+	textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *static_cast<QuartzTextStyle*>(font_.GetID()));
 	textLayout->draw(rc.left, ybase);
 }
 
@@ -942,7 +954,7 @@ static size_t utf8LengthFromLead(unsigned char uch) {
 void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len, XYPOSITION *positions)
 {
 	CFStringEncoding encoding = EncodingFromCharacterSet(unicodeMode, FontCharacterSet(font_));
-	textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *reinterpret_cast<QuartzTextStyle*>(font_.GetID()));
+	textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *static_cast<QuartzTextStyle*>(font_.GetID()));
 
 	CTLineRef mLine = textLayout->getCTLine();
 	assert(mLine != NULL);
@@ -991,7 +1003,7 @@ XYPOSITION SurfaceImpl::WidthText(Font &font_, const char *s, int len) {
   if (font_.GetID())
   {
     CFStringEncoding encoding = EncodingFromCharacterSet(unicodeMode, FontCharacterSet(font_));
-    textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *reinterpret_cast<QuartzTextStyle*>(font_.GetID()));
+    textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *static_cast<QuartzTextStyle*>(font_.GetID()));
 
 	return static_cast<XYPOSITION>(textLayout->MeasureStringWidth());
   }
@@ -1003,7 +1015,7 @@ XYPOSITION SurfaceImpl::WidthChar(Font &font_, char ch) {
   if (font_.GetID())
   {
     CFStringEncoding encoding = EncodingFromCharacterSet(unicodeMode, FontCharacterSet(font_));
-    textLayout->setText (reinterpret_cast<const UInt8*>(str), 1, encoding, *reinterpret_cast<QuartzTextStyle*>(font_.GetID()));
+    textLayout->setText (reinterpret_cast<const UInt8*>(str), 1, encoding, *static_cast<QuartzTextStyle*>(font_.GetID()));
 
     return textLayout->MeasureStringWidth();
   }
@@ -1019,7 +1031,7 @@ XYPOSITION SurfaceImpl::Ascent(Font &font_) {
   if (!font_.GetID())
     return 1;
 
-	float ascent = reinterpret_cast<QuartzTextStyle*>( font_.GetID() )->getAscent();
+	float ascent = static_cast<QuartzTextStyle*>( font_.GetID() )->getAscent();
 	return ascent + 0.5f;
 
 }
@@ -1028,7 +1040,7 @@ XYPOSITION SurfaceImpl::Descent(Font &font_) {
   if (!font_.GetID())
     return 1;
 
-	float descent = reinterpret_cast<QuartzTextStyle*>( font_.GetID() )->getDescent();
+	float descent = static_cast<QuartzTextStyle*>( font_.GetID() )->getDescent();
 	return descent + 0.5f;
 
 }
@@ -1041,7 +1053,7 @@ XYPOSITION SurfaceImpl::ExternalLeading(Font &font_) {
   if (!font_.GetID())
     return 1;
 
-	float leading = reinterpret_cast<QuartzTextStyle*>( font_.GetID() )->getLeading();
+	float leading = static_cast<QuartzTextStyle*>( font_.GetID() )->getLeading();
 	return leading + 0.5f;
 
 }
@@ -1094,33 +1106,19 @@ Window::~Window()
 {
 }
 
-//--------------------------------------------------------------------------------------------------
-
-void Window::Destroy()
-{
-  if (wid)
-  {
-    id idWin = reinterpret_cast<id>(wid);
-    if ([idWin isKindOfClass: [NSWindow class]])
-    {
-      NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
-      [win release];
-    }
-  }
-  wid = 0;
-}
+// Window::Destroy needs to see definition of ListBoxImpl so is located after ListBoxImpl
 
 //--------------------------------------------------------------------------------------------------
 
 bool Window::HasFocus()
 {
-  NSView* container = reinterpret_cast<NSView*>(wid);
+  NSView* container = static_cast<NSView*>(wid);
   return [[container window] firstResponder] == container;
 }
 
 //--------------------------------------------------------------------------------------------------
 
-static CGFloat ScreenMax(NSWindow* win)
+static CGFloat ScreenMax()
 {
   return NSMaxY([[NSScreen mainScreen] frame]);
 }
@@ -1132,12 +1130,12 @@ PRectangle Window::GetPosition()
   if (wid)
   {
     NSRect rect;
-    id idWin = reinterpret_cast<id>(wid);
+    id idWin = static_cast<id>(wid);
     NSWindow* win;
     if ([idWin isKindOfClass: [NSView class]])
     {
       // NSView
-      NSView* view = reinterpret_cast<NSView*>(idWin);
+      NSView* view = idWin;
       win = [view window];
       rect = [view convertRect: [view bounds] toView: nil];
       rect = [win convertRectToScreen:rect];
@@ -1145,10 +1143,10 @@ PRectangle Window::GetPosition()
     else
     {
       // NSWindow
-      win = reinterpret_cast<NSWindow*>(idWin);
+      win = idWin;
       rect = [win frame];
     }
-    CGFloat screenHeight = ScreenMax(win);
+    CGFloat screenHeight = ScreenMax();
     // Invert screen positions to match Scintilla
     return PRectangle(
         static_cast<XYPOSITION>(NSMinX(rect)), static_cast<XYPOSITION>(screenHeight - NSMaxY(rect)),
@@ -1166,13 +1164,13 @@ void Window::SetPosition(PRectangle rc)
 {
   if (wid)
   {
-    id idWin = reinterpret_cast<id>(wid);
+    id idWin = static_cast<id>(wid);
     if ([idWin isKindOfClass: [NSView class]])
     {
       // NSView
       // Moves this view inside the parent view
       NSRect nsrc = NSMakeRect(rc.left, rc.bottom, rc.Width(), rc.Height());
-      NSView* view = reinterpret_cast<NSView*>(idWin);
+      NSView* view = idWin;
       nsrc = [[view window] convertRectFromScreen:nsrc];
       [view setFrame: nsrc];
     }
@@ -1180,8 +1178,8 @@ void Window::SetPosition(PRectangle rc)
     {
       // NSWindow
       PLATFORM_ASSERT([idWin isKindOfClass: [NSWindow class]]);
-      NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
-      CGFloat screenHeight = ScreenMax(win);
+      NSWindow* win = idWin;
+      CGFloat screenHeight = ScreenMax();
       NSRect nsrc = NSMakeRect(rc.left, screenHeight - rc.bottom,
           rc.Width(), rc.Height());
       [win setFrame: nsrc display:YES];
@@ -1215,10 +1213,10 @@ void Window::Show(bool show)
 {
   if (wid)
   {
-    id idWin = reinterpret_cast<id>(wid);
+    id idWin = static_cast<id>(wid);
     if ([idWin isKindOfClass: [NSWindow class]])
     {
-      NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
+      NSWindow* win = idWin;
       if (show)
       {
         [win orderFront:nil];
@@ -1240,17 +1238,17 @@ void Window::InvalidateAll()
 {
   if (wid)
   {
-    id idWin = reinterpret_cast<id>(wid);
+    id idWin = static_cast<id>(wid);
     NSView* container;
     if ([idWin isKindOfClass: [NSView class]])
     {
-      container = reinterpret_cast<NSView*>(idWin);
+      container = idWin;
     }
     else
     {
       // NSWindow
-      NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
-      container = reinterpret_cast<NSView*>([win contentView]);
+      NSWindow* win = idWin;
+      container = [win contentView];
       container.needsDisplay = YES;
     }
     container.needsDisplay = YES;
@@ -1266,17 +1264,17 @@ void Window::InvalidateRectangle(PRectangle rc)
 {
   if (wid)
   {
-    id idWin = reinterpret_cast<id>(wid);
+    id idWin = static_cast<id>(wid);
     NSView* container;
     if ([idWin isKindOfClass: [NSView class]])
     {
-      container = reinterpret_cast<NSView*>(idWin);
+      container = idWin;
     }
     else
     {
       // NSWindow
-      NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
-      container = reinterpret_cast<NSView*>([win contentView]);
+      NSWindow* win = idWin;
+      container = [win contentView];
     }
     [container setNeedsDisplayInRect: PRectangleToNSRect(rc)];
   }
@@ -1299,10 +1297,10 @@ void Window::SetCursor(Cursor curs)
 {
   if (wid)
   {
-    id idWin = reinterpret_cast<id>(wid);
-    if ([idWin isMemberOfClass: [SCIContentView class]])
+    id idWin = static_cast<id>(wid);
+    if ([idWin isKindOfClass: [SCIContentView class]])
     {
-      SCIContentView* container = reinterpret_cast<SCIContentView*>(idWin);
+      SCIContentView* container = idWin;
       [container setCursor: curs];
     }
   }
@@ -1314,10 +1312,10 @@ void Window::SetTitle(const char* s)
 {
   if (wid)
   {
-    id idWin = reinterpret_cast<id>(wid);
+    id idWin = static_cast<id>(wid);
     if ([idWin isKindOfClass: [NSWindow class]])
     {
-      NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
+      NSWindow* win = idWin;
       NSString* sTitle = [NSString stringWithUTF8String:s];
       [win setTitle:sTitle];
     }
@@ -1330,17 +1328,29 @@ PRectangle Window::GetMonitorRect(Point)
 {
   if (wid)
   {
-    id idWin = reinterpret_cast<id>(wid);
+    id idWin = static_cast<id>(wid);
+    if ([idWin isKindOfClass: [NSView class]])
+    {
+      NSView* view = idWin;
+      idWin = [view window];
+    }
     if ([idWin isKindOfClass: [NSWindow class]])
     {
-      NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
+      PRectangle rcPosition = GetPosition();
+
+      NSWindow* win = idWin;
       NSScreen* screen = [win screen];
-      NSRect rect = [screen frame];
+      NSRect rect = [screen visibleFrame];
       CGFloat screenHeight = rect.origin.y + rect.size.height;
       // Invert screen positions to match Scintilla
-      return PRectangle(
+      PRectangle rcWork(
           static_cast<XYPOSITION>(NSMinX(rect)), static_cast<XYPOSITION>(screenHeight - NSMaxY(rect)),
           static_cast<XYPOSITION>(NSMaxX(rect)), static_cast<XYPOSITION>(screenHeight - NSMinY(rect)));
+      PRectangle rcMonitor(rcWork.left - rcPosition.left,
+                           rcWork.top - rcPosition.top,
+                           rcWork.right - rcPosition.left,
+                           rcWork.bottom - rcPosition.top);
+      return rcMonitor;
     }
   }
   return PRectangle();
@@ -1379,6 +1389,8 @@ static NSImage* ImageFromXPM(XPM* pxpm)
 
 //----------------- ListBox and related classes ----------------------------------------------------
 
+//----------------- IListBox -----------------------------------------------------------------------
+
 namespace {
 
 // unnamed namespace hides IListBox interface
@@ -1398,7 +1410,7 @@ public:
 @interface AutoCompletionDataSource :
 NSObject
 #if MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5
-<NSTableViewDataSource, NSTableViewDelegate>
+<NSTableViewDataSource>
 #endif
 {
   IListBox* box;
@@ -1451,20 +1463,6 @@ NSObject
 	return box->Rows();
 }
 
-- (void)tableView: (NSTableView *)tableView
-  willDisplayCell: (id)cell
-   forTableColumn: (NSTableColumn *)tableColumn
-              row: (NSInteger)row
-{
-  if ([cell isKindOfClass: NSTextFieldCell.class])
-  {
-    if (row == tableView.selectedRow)
-      [cell setTextColor: NSColor.whiteColor];
-    else
-      [cell setTextColor: NSColor.darkGrayColor];
-  }
-}
-
 @end
 
 //----------------- ListBoxImpl --------------------------------------------------------------------
@@ -1554,9 +1552,21 @@ private:
   void* doubleClickActionData;
 
 public:
-  ListBoxImpl() : lineHeight(10), unicodeMode(false),
-    desiredVisibleRows(5), maxItemWidth(0), aveCharWidth(8), maxIconWidth(0),
-    doubleClickAction(NULL), doubleClickActionData(NULL)
+  ListBoxImpl() :
+    lineHeight(10),
+    unicodeMode(false),
+    desiredVisibleRows(5),
+    maxItemWidth(0),
+    aveCharWidth(8),
+    maxIconWidth(0),
+    maxWidth(2000),
+    table(nil),
+    scroller(nil),
+    colIcon(nil),
+    colText(nil),
+    ds(nil),
+    doubleClickAction(nullptr),
+    doubleClickActionData(nullptr)
   {
   }
   ~ListBoxImpl() {}
@@ -1586,6 +1596,9 @@ public:
   }
   void SetList(const char* list, char separator, char typesep);
 
+  // To clean up when closed
+  void ReleaseViews();
+
   // For access from AutoCompletionDataSource implement IListBox
   int Rows();
   NSImage* ImageForRow(NSInteger row);
@@ -1602,7 +1615,7 @@ void ListBoxImpl::Create(Window& /*parent*/, int /*ctrlID*/, Scintilla::Point pt
 
   NSRect lbRect = NSMakeRect(pt.x,pt.y, 120, lineHeight * desiredVisibleRows);
   NSWindow* winLB = [[NSWindow alloc] initWithContentRect: lbRect
-    styleMask: NSBorderlessWindowMask
+    styleMask: NSWindowStyleMaskBorderless
     backing: NSBackingStoreBuffered
     defer: NO];
   [winLB setLevel:NSFloatingWindowLevel];
@@ -1628,12 +1641,12 @@ void ListBoxImpl::Create(Window& /*parent*/, int /*ctrlID*/, Scintilla::Point pt
   ds = [[AutoCompletionDataSource alloc] init];
   [ds setBox:this];
   [table setDataSource: ds];	// Weak reference
-  table.delegate = ds;
   [scroller setAutoresizingMask: NSViewWidthSizable | NSViewHeightSizable];
   [[winLB contentView] addSubview: scroller];
 
   [table setTarget:ds];
   [table setDoubleAction:@selector(doubleClick:)];
+  table.selectionHighlightStyle = NSTableViewSelectionHighlightStyleSourceList;
   wid = winLB;
 }
 
@@ -1641,7 +1654,7 @@ void ListBoxImpl::SetFont(Font& font_)
 {
   // NSCell setFont takes an NSFont* rather than a CTFontRef but they
   // are the same thing toll-free bridged.
-  QuartzTextStyle* style = reinterpret_cast<QuartzTextStyle*>(font_.GetID());
+  QuartzTextStyle* style = static_cast<QuartzTextStyle*>(font_.GetID());
   font.Release();
   font.SetID(new QuartzTextStyle(*style));
   NSFont *pfont = (NSFont *)style->getFontRef();
@@ -1683,7 +1696,7 @@ PRectangle ListBoxImpl::GetDesiredRect()
   if (Length() > rows)
   {
     [scroller setHasVerticalScroller:YES];
-    rcDesired.right += [NSScroller scrollerWidthForControlSize:NSRegularControlSize
+    rcDesired.right += [NSScroller scrollerWidthForControlSize:NSControlSizeRegular
 						 scrollerStyle:NSScrollerStyleLegacy];
   }
   else
@@ -1704,6 +1717,21 @@ int ListBoxImpl::CaretFromEdge()
     return 6 + static_cast<int>([colIcon width]);
 }
 
+void ListBoxImpl::ReleaseViews()
+{
+  [table setDataSource:nil];
+  [table release];
+  table = nil;
+  [scroller release];
+  scroller = nil;
+  [colIcon release];
+  colIcon = nil;
+  [colText release ];
+  colText = nil;
+  [ds release];
+  ds = nil;
+}
+
 void ListBoxImpl::Clear()
 {
   maxItemWidth = 0;
@@ -1919,6 +1947,28 @@ ListBox* ListBox::Allocate()
 	return lb;
 }
 
+//--------------------------------------------------------------------------------------------------
+
+void Window::Destroy()
+{
+  ListBoxImpl *listbox = dynamic_cast<ListBoxImpl *>(this);
+  if (listbox)
+  {
+    listbox->ReleaseViews();
+  }
+  if (wid)
+  {
+    id idWin = static_cast<id>(wid);
+    if ([idWin isKindOfClass: [NSWindow class]])
+    {
+      NSWindow* win = static_cast<NSWindow*>(idWin);
+      [win close];
+    }
+  }
+  wid = 0;
+}
+
+
 //----------------- ScintillaContextMenu -----------------------------------------------------------
 
 @implementation ScintillaContextMenu : NSMenu
@@ -1959,7 +2009,7 @@ void Menu::CreatePopUp()
 
 void Menu::Destroy()
 {
-  ScintillaContextMenu* menu = reinterpret_cast<ScintillaContextMenu*>(mid);
+  ScintillaContextMenu* menu = static_cast<ScintillaContextMenu*>(mid);
   [menu release];
   mid = NULL;
 }
