@@ -1,24 +1,31 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "snippet_popover.h"
 
+#include "base/log.h"
+#include "base/drawing.h"
+
 #include "mforms/imagebox.h"
 #include "mforms/textentry.h"
 #include "mforms/label.h"
@@ -28,41 +35,15 @@
 #include "mforms/button.h"
 #include "mforms/box.h"
 
-#include "base/log.h"
-
-using namespace std;
-
 using namespace wb;
 using namespace mforms;
 
-//----------------- Separator ----------------------------------------------------------------------
+//----------------- SnippetPopover -------------------------------------------------------------------------------------
 
-base::Size Separator::getLayoutSize(base::Size proposedSize) {
-  return base::Size(100, 4); // Will be adjusted by the layout process.
-}
-
-//--------------------------------------------------------------------------------------------------
-
-void wb::Separator::repaint(cairo_t* cr, int x, int y, int w, int h) {
-  float width = get_width() + 0.5f;
-
-  cairo_set_line_width(cr, 1);
-
-  cairo_set_source_rgb(cr, 212 / 255.0f, 212 / 255.0f, 212 / 255.0f);
-  cairo_move_to(cr, 0.5f, 0.5f);
-  cairo_line_to(cr, width, 0.5f);
-  cairo_stroke(cr);
-
-  cairo_set_source_rgb(cr, 246 / 255.0f, 246 / 255.0f, 246 / 255.0f);
-  cairo_move_to(cr, 0.5f, 1.5f);
-  cairo_line_to(cr, width, 1.5f);
-  cairo_stroke(cr);
-}
-
-//----------------- SnippetPopover -----------------------------------------------------------------
-
-SnippetPopover::SnippetPopover() : Popover(mforms::PopoverStyleNormal) {
+SnippetPopover::SnippetPopover(mforms::View *owner) : Popover(owner, mforms::PopoverStyleNormal) {
+  setName("Snippet Editor");
   _content = manage(new Box(false));
+  _content->set_name("Snippet Content");
 
   _header = manage(new Box(true));
   _header->set_spacing(10);
@@ -74,21 +55,23 @@ SnippetPopover::SnippetPopover() : Popover(mforms::PopoverStyleNormal) {
   _header->add(image, false, true);
   _header->add(_heading_label, true, true);
 
-  Separator* separator = manage(new Separator());
+  _borderPanel = manage(new Panel(mforms::FilledPanel));
 
-  Panel* border_panel = manage(new Panel(mforms::FilledPanel));
-  border_panel->set_back_color("#cdcdcd");
-  border_panel->set_padding(1);
+  base::Color backgroundColor = base::Color::getSystemColor(base::WindowBackgroundColor);
+  _borderPanel->set_back_color(backgroundColor.to_html());
+
+  _borderPanel->set_padding(1);
   _editor = manage(new CodeEditor());
   _editor->set_language(mforms::LanguageMySQL);
   _editor->set_text("USE SQL CODE;");
   _editor->set_features(mforms::FeatureGutter, false);
   _editor->signal_changed()->connect(
     std::bind(&SnippetPopover::text_changed, this, std::placeholders::_1, std::placeholders::_2));
-  border_panel->add(_editor);
+  _borderPanel->add(_editor);
 
   Box* button_box = manage(new Box(true));
   button_box->set_spacing(8);
+  button_box->set_name("Button bar");
 
   _revert_button = manage(new Button(mforms::ToolButton));
   _revert_button->set_tooltip("Discard all changes and revert to the current version");
@@ -99,6 +82,7 @@ SnippetPopover::SnippetPopover() : Popover(mforms::PopoverStyleNormal) {
     "tiny_undo.png"
 #endif
     ));
+  _revert_button->set_name("Revert");
   _revert_button->signal_clicked()->connect(std::bind(&SnippetPopover::revert_clicked, this));
 
   _edit_button = manage(new Button());
@@ -116,23 +100,26 @@ SnippetPopover::SnippetPopover() : Popover(mforms::PopoverStyleNormal) {
   button_box->add_end(_edit_button, false, true);
 
   _content->add(_header, false, true);
-  _content->add(separator, false, true);
-  _content->add(border_panel, true, true);
+  _content->add(_borderPanel, true, true);
   _content->add_end(button_box, false, true);
   _content->set_spacing(4);
 
   set_content(_content);
+
+  base::NotificationCenter::get()->add_observer(this, "GNColorsChanged");
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 SnippetPopover::~SnippetPopover() {
+  base::NotificationCenter::get()->remove_observer(this);
+
   _heading_label->release();
   _heading_entry->release();
   _content->release();
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void SnippetPopover::revert_clicked() {
   _heading_label->set_text(_original_heading);
@@ -142,26 +129,26 @@ void SnippetPopover::revert_clicked() {
   set_read_only(true);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void SnippetPopover::edit_clicked() {
   set_read_only(false);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void SnippetPopover::close_clicked() {
   close();
   _closed();
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void SnippetPopover::text_changed(int start_line, int lines_changed) {
   _revert_button->set_enabled(true);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void SnippetPopover::set_heading(const std::string& text) {
   _original_heading = text;
@@ -169,7 +156,7 @@ void SnippetPopover::set_heading(const std::string& text) {
   _heading_label->set_text(text);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void SnippetPopover::set_text(const std::string& text) {
   _original_text = text;
@@ -177,7 +164,7 @@ void SnippetPopover::set_text(const std::string& text) {
   _revert_button->set_enabled(false);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void SnippetPopover::set_read_only(bool flag) {
   // We have to exchange a label and a text entry, depending on the read-only state
@@ -199,23 +186,32 @@ void SnippetPopover::set_read_only(bool flag) {
   _edit_button->set_enabled(flag);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 std::string SnippetPopover::get_text() {
   return _editor->get_text(false);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 std::string SnippetPopover::get_heading() {
   return _heading_entry->get_string_value();
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 bool SnippetPopover::has_changed() {
   // We don't have a change event from the text entry so we compare the content instead.
   return _revert_button->is_enabled() || (_heading_entry->get_string_value() != _original_heading);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
+
+void SnippetPopover::handle_notification(const std::string &name, void *sender, base::NotificationInfo &info) {
+  if (name == "GNColorsChanged") {
+    base::Color backgroundColor = base::Color::getSystemColor(base::WindowBackgroundColor);
+    _borderPanel->set_back_color(backgroundColor.to_html());
+  }
+}
+
+//----------------------------------------------------------------------------------------------------------------------
