@@ -22,7 +22,7 @@
  */
 
 #include "gtk/lf_mforms.h"
-#include "sqlide/grid_view.h"
+#include "grid_view.h"
 #include <gtkmm/statusbar.h>
 #include <gtkmm/eventbox.h>
 #include <gtkmm/fixed.h>
@@ -37,8 +37,8 @@
 #include "workbench/wb_overview.h"
 #include "model/wb_context_model.h"
 #include "model/wb_overview_physical.h"
-#include "linux_utilities/plugin_editor_base.h"
-#include "linux_utilities/form_view_base.h"
+#include "plugin_editor_base.h"
+#include "form_view_base.h"
 
 #include "diagram_size_form.h"
 
@@ -49,10 +49,10 @@
 #include "model_panel.h"
 #include "model_diagram_panel.h"
 #include "overview_panel.h"
-#include "find_panel.h"
+#include "mforms/find_panel.h"
 
-#include "linux_utilities/gtk_helpers.h"
-#include "linux_utilities/image_cache.h"
+#include "gtk_helpers.h"
+#include "image_cache.h"
 
 #include "base/string_utilities.h"
 #include "base/geometry.h"
@@ -1484,7 +1484,7 @@ void MainForm::show_page_setup() {
   wb::WBContextUI::get()->get_wb()->execute_plugin("wb.print.setup");
 }
 
-#include <mforms.h>
+#include "mforms/mforms.h"
 #include "gtk/lf_view.h"
 
 static std::string get_resource_path(mforms::App *app, const std::string &file) {
