@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 using System;
@@ -91,11 +95,14 @@ namespace MySQL.Controls
       base.Dispose(disposing);
     }
 
-    public GridView(GridModelWrapper model)
+    public GridView(GridModelWrapper model, Font font = null)
     {
       fieldNullBitmap = Resources.field_overlay_null;
       fieldBlobBitmap = Resources.field_overlay_blob;
 
+      if(font != null)
+        setRowHeight(font);
+
       Model = model;
 
       Dock = DockStyle.Fill;
@@ -106,7 +113,7 @@ namespace MySQL.Controls
       VirtualMode = true;
       AllowUserToOrderColumns = true;
       AllowUserToResizeRows = false;
-      ColumnHeadersHeightSizeMode = DataGridViewColumnHeadersHeightSizeMode.DisableResizing;
+      ColumnHeadersHeightSizeMode = DataGridViewColumnHeadersHeightSizeMode.AutoSize;
       ShowCellToolTips = true;
       SelectionMode = DataGridViewSelectionMode.CellSelect;
 
@@ -116,6 +123,15 @@ namespace MySQL.Controls
 			GridColor = gridColor;
     }
 
+    private void setRowHeight(Font font) 
+    {
+      using(Graphics g = CreateGraphics()) 
+      {
+        SizeF textSize = g.MeasureString("setRowHeight", font);
+        RowTemplate.Height = (int)(Math.Ceiling(textSize.Height) + 2);
+      }
+    }
+
     public GridModelWrapper Model { get; set; }
 
     public void ProcessModelChange()
