@@ -23,6 +23,7 @@
 
 using System;
 using System.Collections.Generic;
+using System.Runtime.InteropServices;
 using System.Windows.Forms;
 
 using MySQL.Base;
@@ -45,7 +46,14 @@ namespace MySQL.Utilities
       return menu;
     }
 
-    public static Keys convertShortcut(String shortcut)
+    [DllImport("user32.dll")]
+    public static extern int ToUnicode(uint virtualKeyCode, uint scanCode,
+                                       byte[] keyboardState,
+                                       [Out, MarshalAs(UnmanagedType.LPWStr, SizeConst = 64)] System.Text.StringBuilder receivingBuffer,
+                                       int bufferSize, uint flags);
+
+
+        public static Keys convertShortcut(String shortcut)
     {
       Keys result = Keys.None;
 
@@ -74,6 +82,15 @@ namespace MySQL.Utilities
               break;
             case "Slash":
               shortcutString = "Divide";
+              Keys key = (Keys)Enum.Parse(typeof(Keys), "Oem2", true);
+
+              var mappedString = new System.Text.StringBuilder(256);
+              ToUnicode((uint)key, 0, new byte[256], mappedString, 256, 0);
+
+              if (mappedString.ToString() == "/") {
+                result |= key;
+                return result;
+              }
               break;
             default:
               shortcutString = k;
@@ -107,6 +124,7 @@ namespace MySQL.Utilities
       {
         Keys shortcut = convertShortcut(subitem.get_shortcut());
 
+
         switch (subitem.get_type())
         {
           case MenuItemType.MenuAction:
