@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 using System;
@@ -24,8 +28,7 @@ using System.Windows.Forms;
 
 using MySQL.Base;
 using MySQL.Controls;
-using MySQL.GUI.Workbench;
-using MySQL.Workbench;
+using MySQL.Utilities;
 
 namespace MySQL.Grt.Db
 {
@@ -51,7 +54,12 @@ namespace MySQL.Grt.Db
 
     public void SetupRecordset(RecordsetWrapper recordset)
     {
-      gridView = new GridView(recordset);
+      Font font = null;
+      string fontName = recordset.getFont();
+      float size = recordset.getFontSize();
+      if(!string.IsNullOrEmpty(fontName) && size > 0)
+        font = ControlUtilities.GetFont(fontName, size);
+      gridView = new GridView(recordset, font);
    //   gridView.Dock = DockStyle.Fill;
       gridView.BorderStyle = BorderStyle.None;
       gridView.StandardTab = false; // Let Tab move the cursor to the next cell instead next control in parent tab order.
@@ -198,6 +206,8 @@ namespace MySQL.Grt.Db
       {
         SortOrder newSortOrder;
 
+        gridView.EndEdit();
+
         // By holding the (left) Alt key we remove any sorting.
         if ((ModifierKeys & Keys.Alt) != 0)
           newSortOrder = SortOrder.None;
@@ -435,7 +445,6 @@ namespace MySQL.Grt.Db
     public void set_font(String font, float size, FontStyle style)
     {
       gridView.Font = new Font(font, size, style);
-      
       // Don't auto resize rows here, as this might be very expensive (e.g. many rows, large cell values).
       gridView.AutoResizeColumnHeadersHeight();
     }
