@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2012, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/file_utilities.h"
@@ -24,7 +28,7 @@
 
 using namespace base;
 
-#ifdef _WIN32
+#ifdef _MSC_VER
 #define FILE_SEPARATOR "\\"
 #define INVALID_NAME "__test_file01*?"
 #define RESERVED_NAME "com1"
@@ -240,7 +244,7 @@ TEST_FUNCTION(10) {
     throw grt::os_error(strfmt("Cannot create directory for document: %s", exc.what()));
   }
 
-#ifdef _WIN32
+#ifdef _MSC_VER
   // Create a directory -- Reserved name. This will not fail in linux, returning false (already exists)
   try {
     base::create_directory(RESERVED_NAME, 0700);
@@ -264,7 +268,7 @@ TEST_FUNCTION(10) {
   } catch (base::file_error &exc) {
     throw grt::os_error(strfmt("Cannot create file for document: %s", exc.what()));
   }
-#ifdef _WIN32
+#ifdef _MSC_VER
   // Remove a file/directory -- Invalid name
   try {
     base::remove(INVALID_NAME);
@@ -682,7 +686,7 @@ TEST_FUNCTION(35) {
       fail(strfmt("TEST 35.3: File with too long name threw an unexpected error: %s", exc.what()));
     }
 
-#ifdef _WIN32
+#ifdef _MSC_VER
     // test case for 'throw_on_fail' default value (i.e. TRUE)
     // -- Unicode name (file doesn't exist)
     try {
@@ -776,12 +780,12 @@ TEST_FUNCTION(35) {
  */
 TEST_FUNCTION(40) {
   try {
-    // constructors & miscellaneous variables
+//     constructors & miscellaneous variables
     base::FileHandle c_tor_no_name;
     base::FileHandle c_tor_test_filename(TEST_FILE_NAME01, "w+");
     base::FileHandle c_tor_temp(TEST_FILE_NAME02, "w+");
     FILE *original_c_tor_temp_ptr = c_tor_temp.file();
-    base::FileHandle c_tor_FileHandle_ref(c_tor_temp);
+    base::FileHandle *c_tor_FileHandle_ref = new base::FileHandle(c_tor_temp);
 
     // test case for empty name string
     FILE *test_result = c_tor_no_name.file();
@@ -811,14 +815,14 @@ TEST_FUNCTION(40) {
     }
 
     // test case for FileHandle& value
-    test_result = c_tor_FileHandle_ref.file();
+    test_result = c_tor_FileHandle_ref->file();
     expected_result = original_c_tor_temp_ptr;
 
     ensure_equals("TEST 40.5: Unexpected result calling FileHandle constructor", test_result, expected_result);
 
     // test case for d-tor
-    c_tor_FileHandle_ref.~FileHandle();
-    test_result = c_tor_FileHandle_ref.file();
+    c_tor_FileHandle_ref->~FileHandle();
+    test_result = c_tor_FileHandle_ref->file();
     expected_result = NULL;
 
     ensure_equals("TEST 40.6: Unexpected result calling FileHandle destructor", test_result, expected_result);
@@ -877,7 +881,7 @@ TEST_FUNCTION(45) {
     } catch (std::exception &exc) {
       fail(strfmt("TEST 45.3: File with too long name threw an unexpected error: %s", exc.what()));
     }
-#ifdef _WIN32
+#ifdef _MSC_VER
     // test case for 'throw_on_fail' default value (i.e. TRUE)
     // -- Unicode name (file doesn't exist)
     try {
@@ -1174,7 +1178,7 @@ TEST_FUNCTION(53) {
       fail(strfmt("TEST 53.8: 'is_directory()' returned TRUE for a unicode name"));
     }
 
-#ifdef _WIN32
+#ifdef _MSC_VER
     // -- Reserved name
     if (base::is_directory(RESERVED_NAME)) {
       // return true means directory exists
@@ -1392,7 +1396,7 @@ TEST_FUNCTION(53) {
     } catch (std::exception &exc) {
       fail(strfmt("TEST 53.31: Non-existing file \"%s\" threw an unexpected error: %s", TEST_FILE_NAME03, exc.what()));
     }
-#ifdef _WIN32
+#ifdef _MSC_VER
     // -- Target File already exists
     try {
       // Create file
@@ -1453,7 +1457,7 @@ TEST_FUNCTION(53) {
     test_result = base::extension(file_unicode_name.c_str());
     ensure_equals("TEST 53.38: Unexpected result getting file extension", test_result, ".txt");
 
-#ifdef _WIN32
+#ifdef _MSC_VER
     // -- Reserved name
     test_result.clear();
     test_result = base::extension(RESERVED_NAME);
@@ -1504,7 +1508,7 @@ TEST_FUNCTION(53) {
     ensure_equals("TEST 53.47: Unexpected result calling strip_extension()", test_result,
                   file_unicode_basename.c_str());
 
-#ifdef _WIN32
+#ifdef _MSC_VER
     // -- Reserved name
     test_result.clear();
     test_result = base::strip_extension(RESERVED_NAME);
@@ -1558,7 +1562,7 @@ TEST_FUNCTION(53) {
       // return false means dir does not exist
       fail("TEST 53.56: Directory with Unicode name does not exist");
     }
-#ifdef _WIN32
+#ifdef _MSC_VER
     // -- Reserved name
     if (base::remove_recursive(RESERVED_NAME)) {
       // return true means dir exists
@@ -1584,7 +1588,7 @@ TEST_FUNCTION(53) {
  * - remove_recursive(const std::string &path)
  * -- Read-only permissions --
  */
-#ifdef _WIN32
+#ifdef _MSC_VER
 TEST_FUNCTION(54) {
   std::string command_line;
 
@@ -1804,7 +1808,7 @@ TEST_FUNCTION(60) {
     try {
       base::file_locked_error error("File Locked Error Message");
       throw(error);
-    } catch (const base::file_locked_error) {
+    } catch (const base::file_locked_error &) {
       // Nothing to do, just catch the error and continue.
     }
 
@@ -1812,7 +1816,7 @@ TEST_FUNCTION(60) {
       base::file_locked_error first_error("File Locked Error Message");
       base::file_locked_error second_error(first_error);
       throw(second_error);
-    } catch (const base::file_locked_error) {
+    } catch (const base::file_locked_error &) {
       // Nothing to do, just catch the error and continue.
     }
 
@@ -1843,7 +1847,7 @@ TEST_FUNCTION(65) {
         if (LockFile::check(TEST_FILE_NAME01) != LockFile::LockedSelf)
           fail(strfmt("TEST 65.1: File \"%s\" not locked", TEST_FILE_NAME01));
 
-#ifndef _WIN32
+#ifndef _MSC_VER
         // Semantic issue with NotLocked for a plain file without content.
         // TODO: rework lock detection with other than base::LockFile instances.
         if (LockFile::check(TEST_FILE_NAME02) != LockFile::NotLocked)
@@ -1867,7 +1871,7 @@ TEST_FUNCTION(65) {
   remove(TEST_FILE_NAME02);
 }
 
-#ifdef _WIN32
+#ifdef _MSC_VER
 /*
  * Child thread function
  */
@@ -2048,7 +2052,7 @@ TEST_FUNCTION(75) {
   ensure_equals("TEST 75.16", base::relativePath("🍏🍎🍐/ЀЁЂ\\ᚋᚌᚍ/last", "🍏🍎🍐"), "../../../");
 
 // Case sensitivity.
-#ifdef _WIN32
+#ifdef _MSC_VER
   ensure_equals("TEST 75.17", base::relativePath("/🍏🍎🍐/ЀЁЂ\\ᚋᚌᚍ\\last", "\\Last"), "../../../../Last");
   ensure_equals("TEST 75.18", base::relativePath("/XYZ/🍏🍎🍐/ЀЁЂ\\ᚋᚌᚍ\\last", "\\xyz\\Last"), "../../../../Last");
 #else
