@@ -1,28 +1,41 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/sqlstring.h"
 #include "base/string_utilities.h"
 #include "wb_helpers.h"
 
+#ifdef __APPLE__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcomma"
+#endif
+
 #include <boost/lexical_cast.hpp>
 
+#ifdef __APPLE__
+#pragma GCC diagnostic pop
+#endif
+
 using namespace base;
 
 #define MAX_SIZE_RANDOM_VALUES_ARRAY 25
@@ -373,7 +386,7 @@ TEST_FUNCTION(25) {
     test_result.clear();
     test_result.append(sqlstring("eleventh_test !", QuoteOnlyIfNeeded) << null_str);
     fail("TEST 25.11: Unexpected result quoting null string");
-  } catch (std::invalid_argument e) {
+  } catch (std::invalid_argument &e) {
     // Nothing to do, just catch the error and continue
   }
 
@@ -381,7 +394,7 @@ TEST_FUNCTION(25) {
     test_result.clear();
     test_result.append(sqlstring("twelfth_test !", UseAnsiQuotes) << null_str);
     fail("TEST 25.12: Unexpected result quoting null string");
-  } catch (std::invalid_argument e) {
+  } catch (std::invalid_argument &e) {
     // Nothing to do, just catch the error and continue
   }
 }
