@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -30,6 +30,7 @@
 
 @implementation MFRadioButtonImpl
 
+//----------------------------------------------------------------------------------------------------------------------
 
 - (instancetype)initWithObject:(::mforms::RadioButton*)aRadioButton
 {
@@ -49,6 +50,8 @@
   return self;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (instancetype)initWithObject: (mforms::Button *)button buttonType: (mforms::ButtonType)type
 {
   mforms::RadioButton *radio = dynamic_cast<mforms::RadioButton *>(button);
@@ -57,22 +60,47 @@
   return [self initWithObject: radio];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (void)performCallback:(id)sender
 {
   dynamic_cast<mforms::RadioButton*>(mOwner)->callback();
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (NSSize)minimumSize
 {
   NSSize size = super.minimumSize;
   return { MAX(self.cell.cellSize.width, size.width), MAX(self.cell.cellSize.height, size.height) };
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityRadioButtonRole;
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
+- (nullable NSNumber *)accessibilityValue {
+    MFRadioButtonImpl* radiobutton = mOwner->get_data();
+    short int value = 0;
+    if(radiobutton.state == NSOnState)
+        value = 1;
+    else if (radiobutton.state == NSMixedState)
+        value = 2;
+    return @(value);
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
 static bool radiobutton_create(::mforms::RadioButton *self, int)
 {
   return [[MFRadioButtonImpl alloc] initWithObject: self] != nil;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void radiobutton_set_active(::mforms::RadioButton *self, bool flag)
 {
@@ -87,6 +115,8 @@ static void radiobutton_set_active(::mforms::RadioButton *self, bool flag)
   }
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 static bool radiobutton_get_active(::mforms::RadioButton *self)
 {
   if ( self )
@@ -101,6 +131,7 @@ static bool radiobutton_get_active(::mforms::RadioButton *self)
   return false;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 void cf_radiobutton_init()
 {
@@ -111,6 +142,4 @@ void cf_radiobutton_init()
   f->_radio_impl.get_active= &radiobutton_get_active;
 }
 
-
 @end
-
