@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -79,6 +79,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   return self;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityMenuBarItemRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -152,6 +158,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   return mOwner->get_type();
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityMenuBarItemRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -308,10 +320,18 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   [self sizeToFit];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (NSString*)stringValue {
   return self.title;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityButtonRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -383,6 +403,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   [mToolbar resizeSubviewsWithOldSize: NSZeroSize];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityStaticTextRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -437,6 +463,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   [self setFrameSize: image.size];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityImageRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -493,6 +525,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   mOwner->callback();
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityTextFieldRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -540,6 +578,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   return mOwner;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityTextFieldRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -613,6 +657,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
     [self selectItemWithTitle: value];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityPopUpButtonRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -925,6 +975,12 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   [self removeFromSuperview];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityMenuBarRole;
+}
+
 @end
 
 //----------------------------------------------------------------------------------------------------------------------
