@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #pragma once
@@ -43,6 +47,7 @@ namespace mforms {
     bool (*create_menu_item)(MenuItem *item, const std::string &, const MenuItemType type);
     void (*set_title)(MenuItem *item, const std::string &);
     std::string (*get_title)(MenuItem *item);
+    void (*set_name)(MenuItem *item, const std::string &);
     void (*set_shortcut)(MenuItem *item, const std::string &);
     void (*set_enabled)(MenuBase *item, bool);
     bool (*get_enabled)(MenuBase *item);
@@ -81,9 +86,9 @@ namespace mforms {
     int item_count();
 
 #ifndef SWIG
-    MenuItem *add_item_with_title(const std::string &title, std::function<void()> action, const std::string &name = "");
+    MenuItem *add_item_with_title(const std::string &title, std::function<void()> action, const std::string &name, const std::string &internalName);
     MenuItem *add_check_item_with_title(const std::string &title, std::function<void()> action,
-                                        const std::string &name = "");
+                                        const std::string &name, const std::string &internalName);
 #endif
     MenuItem *add_separator();
 
@@ -121,6 +126,8 @@ namespace mforms {
     void set_title(const std::string &title);
     std::string get_title();
 
+    void set_name(const std::string &name);
+
     void set_shortcut(const std::string &shortcut);
     std::string get_shortcut() {
       return _shortcut;
@@ -134,9 +141,11 @@ namespace mforms {
       return &_clicked_signal;
     }
 #endif
-    void set_name(const std::string &name);
-    std::string get_name() {
-      return _name;
+    void setInternalName(const std::string &name) {
+        _internalName = name;
+    }
+    std::string getInternalName() {
+      return _internalName;
     }
 
     MenuItemType get_type() {
@@ -151,7 +160,7 @@ namespace mforms {
     virtual void validate();
 
   private:
-    std::string _name;
+    std::string _internalName;
     std::string _shortcut;
     std::vector<validator_function> _validators;
     boost::signals2::signal<void()> _clicked_signal;
