@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 using System;
@@ -108,7 +112,7 @@ namespace MySQL.GUI.Workbench.Plugins
         if (insertsTabPage.Controls.Count > 0)
           insertsTabPage.Controls.Clear();
 
-        Backend = new MySQLTableEditorWrapper(GrtManager, value);
+        Backend = new MySQLTableEditorWrapper(value);
 
         Control panel = tableEditorBE.get_trigger_panel();
         triggersTabPage.Controls.Add(panel);
@@ -230,18 +234,21 @@ namespace MySQL.GUI.Workbench.Plugins
 
       System.Collections.Generic.List<String> collations_list = tableEditorBE.get_charset_collation_list();
 
+      var charsetLlist = tableEditorBE.get_charset_list();
+      optCharset.Items.Clear();
+      optCharset.Items.AddRange(charsetLlist.ToArray());
+
       optCollation.Items.Clear();
-      optCollation.Items.Add("Schema Default");
+      optCollation.Items.Add("Default Collation");
 
       columnCollationComboBox.Enabled = false;
       columnCollationComboBox.Items.Clear();
-      columnCollationComboBox.Items.Add("Table Default");
+      columnCollationComboBox.Items.Add("Default Collation");
+
+      columnCharsetComboBox.Enabled = false;
+      columnCharsetComboBox.Items.Clear();
+      columnCharsetComboBox.Items.AddRange(charsetLlist.ToArray());
 
-      foreach (String coll in collations_list)
-      {
-        optCollation.Items.Add(coll);
-        columnCollationComboBox.Items.Add(coll);
-      }
 
       // This validation was added to avoid removing the page if not needed
       // as it causes flickering
@@ -477,19 +484,25 @@ namespace MySQL.GUI.Workbench.Plugins
         else
           optEngine.Text = eng;
 
-        int idx = 0;
-        optCollation.SelectedIndex = 0;
-        String cscoll = tableEditorBE.get_table_option_by_name("CHARACTER SET - COLLATE");
 
-        foreach (String next_cscoll in optCollation.Items)
-        {
-          if (next_cscoll == cscoll)
-          {
-            optCollation.SelectedIndex = idx;
-            break;
-          }
-          idx++;
-        }
+        var charset = tableEditorBE.get_table_option_by_name("CHARACTER SET");
+        var idx = optCharset.FindString(charset);
+        if (idx < 0)
+          idx = 0;
+        optCharset.SelectedIndex = idx;
+
+        var selectedValue = "Default Charset";
+        if (optCharset.SelectedItem != null)
+          selectedValue = optCharset.SelectedItem.ToString();
+        var collation = tableEditorBE.get_charset_collation_list(selectedValue);
+        optCollation.Items.Clear();
+        optCollation.Items.AddRange(collation.ToArray());
+
+        var collate = tableEditorBE.get_table_option_by_name("COLLATE");
+        idx = optCollation.FindString(charset);
+        if (idx < 0)
+          idx = 0;
+        optCollation.SelectedIndex = idx;
 
         TabText = tableEditorBE.get_title();
 
@@ -676,29 +689,25 @@ namespace MySQL.GUI.Workbench.Plugins
           (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.HasCharset, out hasCharset) &&
           (hasCharset == "1"))
         {
-          String column_cscoll;
+
+          var charset = "";
           columnsListModel.GrtList.get_field(nodeId,
-            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.CharsetCollation, out column_cscoll);
+            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.Charset, out charset);
 
+          columnCharsetComboBox.Enabled = true;
           columnCollationComboBox.Enabled = true;
-
-          int idx = 0;
-          columnCollationComboBox.SelectedIndex = 0;
-
-          foreach (String next_cscoll in columnCollationComboBox.Items)
-          {
-            if (next_cscoll == column_cscoll)
-            {
-              columnCollationComboBox.SelectedIndex = idx;
-              break;
-            }
-            idx++;
-          }
+          var idx = columnCharsetComboBox.FindString(charset);
+          if (idx < 0)
+            idx = 0;
+          columnCharsetComboBox.SelectedIndex = idx;
         }
         else
         {
+          columnCharsetComboBox.SelectedIndex = 0;
+          columnCharsetComboBox.Enabled = false;
           columnCollationComboBox.SelectedIndex = 0;
           columnCollationComboBox.Enabled = false;
+
         }
 
         if (columnsListModel.GrtList.get_field(nodeId,
@@ -881,6 +890,7 @@ namespace MySQL.GUI.Workbench.Plugins
         columnCommentTextBox.Enabled = false;
         columnCommentTextBox.Text = "";
         columnCollationComboBox.Enabled = false;
+        columnCharsetComboBox.Enabled = false;
         columnNameTextBox.Text = "";
         columnNameTextBox.Enabled = false;
         columnDataTypeTextBox.Text = "";
@@ -920,17 +930,53 @@ namespace MySQL.GUI.Workbench.Plugins
         if (columnCollationComboBox.SelectedIndex == 0)
         {
           columnsListModel.GrtList.set_field(nodeId,
-            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.CharsetCollation, "");
+            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.Collation, "");
         }
         else
         {
           columnsListModel.GrtList.set_field(nodeId,
-            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.CharsetCollation,
+            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.Collation,
               columnCollationComboBox.Text);
         }
       }
     }
 
+    private void columnCharsetComboBox_SelectedIndexChanged(object sender, EventArgs e)
+    {
+      // set charset
+      if (columnsTreeView.SelectedNode != null)
+      {
+        NodeIdWrapper nodeId = new NodeIdWrapper(columnsTreeView.SelectedNode.Index);
+        if (columnCharsetComboBox.SelectedIndex == 0)
+        {
+          columnsListModel.GrtList.set_field(nodeId,
+            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.Charset, "");
+          columnCollationComboBox.Enabled = false;
+          columnCollationComboBox.SelectedIndex = 0;
+        }
+        else
+        {
+          columnsListModel.GrtList.set_field(nodeId,
+            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.Charset,
+              columnCharsetComboBox.Text);
+          var collation = tableEditorBE.get_charset_collation_list(columnCharsetComboBox.Text);
+          columnCollationComboBox.Items.Clear();
+          columnCollationComboBox.Items.AddRange(collation.ToArray());
+          var collationItem = "";
+          columnsListModel.GrtList.get_field(nodeId,
+            (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.Collation, out collationItem);
+          int idx = columnCollationComboBox.FindString(collationItem);
+          if (idx < 0) {
+            columnsListModel.GrtList.set_field(nodeId,
+              (int)MySQLTableColumnsListWrapper.MySQLColumnListColumns.Collation, "");
+            idx = 0;
+          }
+          columnCollationComboBox.Enabled = true;
+          columnCollationComboBox.SelectedIndex = idx;
+        }
+      }
+    }
+
     private void updateColumnTextField(MySQLTableColumnsListWrapper.MySQLColumnListColumns column, TextBox box)
     {
       if (columnsTreeView.SelectedNode != null)
@@ -1098,7 +1144,8 @@ namespace MySQL.GUI.Workbench.Plugins
 
         if (node != null)
         {
-          indexCommentText.Enabled = tableEditorBE.is_server_version_at_least(5, 5);
+          indexCommentText.Enabled = tableEditorBE.is_server_version_at_least(5, 5, -1);
+          visibleCheckBox.Enabled = false;
           indexStorageTypeComboBox.Enabled = true;
           indexRowBlockSizeText.Enabled = true;
           indexParserText.Enabled = true;
@@ -1130,6 +1177,20 @@ namespace MySQL.GUI.Workbench.Plugins
           indexRowBlockSizeText.Text = value;
           ilist.get_field(node.NodeId, (int)MySQLIndexListWrapper.Columns.Parser, out value);
           indexParserText.Text = value;
+
+          if (tableEditorBE.is_server_version_at_least(8, 0, 0))
+          {
+            String type = "";
+            ilist.get_field(node.NodeId, (int)MySQLIndexListWrapper.Columns.Type, out type);
+            int visible = 1;
+            if (type != "PRIMARY")
+              ilist.get_field(node.NodeId, (int)MySQLIndexListWrapper.Columns.Visible, out visible);
+            visibleCheckBox.Checked = visible == 1;
+            if (type == "PRIMARY" || (type == "UNIQUE" && ilist.count() == 2))
+              visibleCheckBox.Enabled = false;
+            else
+              visibleCheckBox.Enabled = true;
+          }
         }
         else
         {
@@ -1143,6 +1204,8 @@ namespace MySQL.GUI.Workbench.Plugins
           indexStorageTypeComboBox.Enabled = false;
           indexRowBlockSizeText.Enabled = false;
           indexParserText.Enabled = false;
+          visibleCheckBox.Enabled = false;
+          visibleCheckBox.Checked = false;
         }
       }
       else
@@ -1157,6 +1220,8 @@ namespace MySQL.GUI.Workbench.Plugins
         indexStorageTypeComboBox.Enabled = false;
         indexRowBlockSizeText.Enabled = false;
         indexParserText.Enabled = false;
+        visibleCheckBox.Enabled = false;
+        visibleCheckBox.Checked = false;
       }
     }
 
@@ -1201,6 +1266,18 @@ namespace MySQL.GUI.Workbench.Plugins
       }
     }
 
+    void visibleChanged(object sender, System.EventArgs e) 
+    {
+      if (indicesTreeView.SelectedNode != null)
+      {
+        GrtListNode node = indicesTreeView.SelectedNode.Tag as GrtListNode;
+        if (node != null) {
+          int value = visibleCheckBox.Checked ? 1 : 0;
+          tableEditorBE.get_indexes().set_field(node.NodeId, (int)MySQLIndexListWrapper.Columns.Visible, value);
+        }
+      }
+    }
+
     void indexRowBlockSizeText_TextChanged(object sender, System.EventArgs e)
     {
       if (indicesTreeView.SelectedNode != null)
@@ -1272,7 +1349,7 @@ namespace MySQL.GUI.Workbench.Plugins
 
     #region Options
 
-    private void setTableOpt()
+    private void setTableOpt(string controlName)
     {
       switch (optPackKeys.SelectedIndex)
       {
@@ -1377,17 +1454,28 @@ namespace MySQL.GUI.Workbench.Plugins
 
       tableEditorBE.set_table_option_by_name("ENGINE", eng);
 
-      // set charset/collation
-      if (optCollation.SelectedIndex == 0)
-      {
-        tableEditorBE.set_table_option_by_name("CHARACTER SET - COLLATE", "");
+      if(controlName == "optCharset") { 
+        // set charset
+        if (optCharset.SelectedIndex == 0) {
+          tableEditorBE.set_table_option_by_name("CHARACTER SET", "");
+          optCollation.Items.Clear();
+          optCollation.Items.Add("Default Collation");
+          optCollation.SelectedIndex = 0;
+        } else {
+          tableEditorBE.set_table_option_by_name("CHARACTER SET", optCharset.Text);
+          var collation = tableEditorBE.get_charset_collation_list(optCharset.Text);
+          optCollation.Items.Clear();
+          optCollation.Items.AddRange(collation.ToArray());
+          optCollation.SelectedIndex = 0;
+        }
       }
-      else
-      {
-        int cs_sep = optCollation.Text.IndexOf('-');
-        if (cs_sep != -1)
-        {
-          tableEditorBE.set_table_option_by_name("CHARACTER SET - COLLATE", optCollation.Text);
+
+      if (controlName == "optCollation") {
+        // set collation
+        if (optCollation.SelectedIndex == 0) {
+          tableEditorBE.set_table_option_by_name("COLLATE", "");
+        } else {
+          tableEditorBE.set_table_option_by_name("COLLATE", optCollation.Text);
         }
       }
     }
@@ -1400,7 +1488,9 @@ namespace MySQL.GUI.Workbench.Plugins
         updatingTable = true;
         try
         {
-          setTableOpt();
+          var control = (Control)sender;
+          var name = control != null ? control.Name : "";
+          setTableOpt(name);
         }
         finally
         {
@@ -1434,7 +1524,12 @@ namespace MySQL.GUI.Workbench.Plugins
 
     private void DbMysqlTableEditor_Shown(object sender, EventArgs e)
     {
-      nameTextBox.Focus();
+      DbMysqlTableEditor editor = (DbMysqlTableEditor)sender;
+      if(sender != null) 
+      {
+        editor.Focus();
+        editor.nameTextBox.Focus();
+      }
     }
 
     #endregion
